@@ -98,6 +98,10 @@ class TaSignals:
 
         data = {'ema20': df['ema20'].iloc[-1], 'ema50': df['ema50'].iloc[-1], 'ema100': df['ema100'].iloc[-1], 'ema200': df['ema200'].iloc[-1]}
         data = [
+            {'key': 'key_below_ema34', 'value': 'Key below EMA34' if df[key].iloc[-1] < df['ema34'].iloc[-1] else False},
+            {'key': 'key_below_ema8', 'value': 'Key below EMA8' if df[key].iloc[-1] < df['ema38'].iloc[-1] else False},
+            {'key': 'key_above_ema34', 'value': 'Key above EMA34' if df[key].iloc[-1] > df['ema34'].iloc[-1] else False},
+            {'key': 'key_above_ema8', 'value': 'Key above EMA8' if df[key].iloc[-1] > df['ema8'].iloc[-1] else False},
             {'key': 'ema_8_dropping', 'value': 'EMA8 is dropping' if df['ema8_slope'].iloc[-1] < 0 else False},
             {'key': 'ema_8_rising_fast', 'value': 'EMA8 is rising fast' if df['ema8_slope'].iloc[-1] > 3 else False},
             {'key': 'ema_8_rising', 'value': 'EMA8 is rising' if df['ema8_slope'].iloc[-1] > 0 else False},
